# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LeadFormFieldUserInputTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LeadFormFieldUserInputTypeValue = typing___NewType(
        "LeadFormFieldUserInputTypeValue", builtin___int
    )
    type___LeadFormFieldUserInputTypeValue = LeadFormFieldUserInputTypeValue
    LeadFormFieldUserInputType: _LeadFormFieldUserInputType
    class _LeadFormFieldUserInputType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 0
        )
        UNKNOWN = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1
        )
        FULL_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 2
        )
        GIVEN_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 6
        )
        FAMILY_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 7
        )
        EMAIL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 3
        )
        PHONE_NUMBER = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 4
        )
        POSTAL_CODE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 5
        )
        CITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 9
        )
        REGION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 10
        )
        COUNTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 11
        )
        WORK_EMAIL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 12
        )
        COMPANY_NAME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 13
        )
        WORK_PHONE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 14
        )
        JOB_TITLE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 15
        )
        VEHICLE_MODEL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1001
        )
        VEHICLE_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1002
        )
        PREFERRED_DEALERSHIP = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1003
        )
        VEHICLE_PURCHASE_TIMELINE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1004
        )
        VEHICLE_OWNERSHIP = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1005
        )
        VEHICLE_PAYMENT_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1009
        )
        VEHICLE_CONDITION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1010
        )
        COMPANY_SIZE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1006
        )
        ANNUAL_SALES = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1007
        )
        YEARS_IN_BUSINESS = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1008
        )
        JOB_DEPARTMENT = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1011
        )
        JOB_ROLE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1012
        )
        EDUCATION_PROGRAM = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1013
        )
        EDUCATION_COURSE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1014
        )
        PRODUCT = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1016
        )
        SERVICE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1017
        )
        OFFER = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1018
        )
        CATEGORY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1019
        )
        PREFERRED_CONTACT_METHOD = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1020
        )
        PREFERRED_LOCATION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1021
        )
        PREFERRED_CONTACT_TIME = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1022
        )
        PURCHASE_TIMELINE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1023
        )
        YEARS_OF_EXPERIENCE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1048
        )
        JOB_INDUSTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1049
        )
        LEVEL_OF_EDUCATION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1050
        )
        PROPERTY_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1024
        )
        REALTOR_HELP_GOAL = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1025
        )
        PROPERTY_COMMUNITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1026
        )
        PRICE_RANGE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1027
        )
        NUMBER_OF_BEDROOMS = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1028
        )
        FURNISHED_PROPERTY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1029
        )
        PETS_ALLOWED_PROPERTY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1030
        )
        NEXT_PLANNED_PURCHASE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1031
        )
        EVENT_SIGNUP_INTEREST = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1033
        )
        PREFERRED_SHOPPING_PLACES = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1034
        )
        FAVORITE_BRAND = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1035
        )
        TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1036
        )
        EVENT_BOOKING_INTEREST = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1038
        )
        DESTINATION_COUNTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1039
        )
        DESTINATION_CITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1040
        )
        DEPARTURE_COUNTRY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1041
        )
        DEPARTURE_CITY = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1042
        )
        DEPARTURE_DATE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1043
        )
        RETURN_DATE = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1044
        )
        NUMBER_OF_TRAVELERS = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1045
        )
        TRAVEL_BUDGET = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1046
        )
        TRAVEL_ACCOMMODATION = typing___cast(
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1047
        )
    UNSPECIFIED = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 0
    )
    UNKNOWN = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1
    )
    FULL_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 2
    )
    GIVEN_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 6
    )
    FAMILY_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 7
    )
    EMAIL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 3
    )
    PHONE_NUMBER = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 4
    )
    POSTAL_CODE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 5
    )
    CITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 9
    )
    REGION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 10
    )
    COUNTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 11
    )
    WORK_EMAIL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 12
    )
    COMPANY_NAME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 13
    )
    WORK_PHONE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 14
    )
    JOB_TITLE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 15
    )
    VEHICLE_MODEL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1001
    )
    VEHICLE_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1002
    )
    PREFERRED_DEALERSHIP = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1003
    )
    VEHICLE_PURCHASE_TIMELINE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1004
    )
    VEHICLE_OWNERSHIP = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1005
    )
    VEHICLE_PAYMENT_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1009
    )
    VEHICLE_CONDITION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1010
    )
    COMPANY_SIZE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1006
    )
    ANNUAL_SALES = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1007
    )
    YEARS_IN_BUSINESS = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1008
    )
    JOB_DEPARTMENT = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1011
    )
    JOB_ROLE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1012
    )
    EDUCATION_PROGRAM = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1013
    )
    EDUCATION_COURSE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1014
    )
    PRODUCT = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1016
    )
    SERVICE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1017
    )
    OFFER = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1018
    )
    CATEGORY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1019
    )
    PREFERRED_CONTACT_METHOD = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1020
    )
    PREFERRED_LOCATION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1021
    )
    PREFERRED_CONTACT_TIME = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1022
    )
    PURCHASE_TIMELINE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1023
    )
    YEARS_OF_EXPERIENCE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1048
    )
    JOB_INDUSTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1049
    )
    LEVEL_OF_EDUCATION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1050
    )
    PROPERTY_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1024
    )
    REALTOR_HELP_GOAL = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1025
    )
    PROPERTY_COMMUNITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1026
    )
    PRICE_RANGE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1027
    )
    NUMBER_OF_BEDROOMS = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1028
    )
    FURNISHED_PROPERTY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1029
    )
    PETS_ALLOWED_PROPERTY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1030
    )
    NEXT_PLANNED_PURCHASE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1031
    )
    EVENT_SIGNUP_INTEREST = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1033
    )
    PREFERRED_SHOPPING_PLACES = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1034
    )
    FAVORITE_BRAND = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1035
    )
    TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1036
    )
    EVENT_BOOKING_INTEREST = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1038
    )
    DESTINATION_COUNTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1039
    )
    DESTINATION_CITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1040
    )
    DEPARTURE_COUNTRY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1041
    )
    DEPARTURE_CITY = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1042
    )
    DEPARTURE_DATE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1043
    )
    RETURN_DATE = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1044
    )
    NUMBER_OF_TRAVELERS = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1045
    )
    TRAVEL_BUDGET = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1046
    )
    TRAVEL_ACCOMMODATION = typing___cast(
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputTypeValue, 1047
    )
    type___LeadFormFieldUserInputType = LeadFormFieldUserInputType
    def __init__(self,) -> None: ...

type___LeadFormFieldUserInputTypeEnum = LeadFormFieldUserInputTypeEnum



from typing import Any

class AccountBudgetProposalServiceStub:
    GetAccountBudgetProposal: Any = ...
    MutateAccountBudgetProposal: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AccountBudgetProposalServiceServicer:
    def GetAccountBudgetProposal(self, request: Any, context: Any) -> None: ...
    def MutateAccountBudgetProposal(self, request: Any, context: Any) -> None: ...

def add_AccountBudgetProposalServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class CampaignBidModifierServiceStub:
    GetCampaignBidModifier: Any = ...
    MutateCampaignBidModifiers: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignBidModifierServiceServicer:
    def GetCampaignBidModifier(self, request: Any, context: Any) -> None: ...
    def MutateCampaignBidModifiers(self, request: Any, context: Any) -> None: ...

def add_CampaignBidModifierServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.placement_type_pb2 import (
    PlacementTypeEnum as google___ads___googleads___v5___enums___placement_type_pb2___PlacementTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GroupPlacementView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    placement_type: google___ads___googleads___v5___enums___placement_type_pb2___PlacementTypeEnum.PlacementTypeValue = ...
    @property
    def placement(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def display_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def target_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        placement: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        display_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        target_url: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        placement_type: typing___Optional[
            google___ads___googleads___v5___enums___placement_type_pb2___PlacementTypeEnum.PlacementTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "display_name",
            b"display_name",
            "placement",
            b"placement",
            "target_url",
            b"target_url",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "display_name",
            b"display_name",
            "placement",
            b"placement",
            "placement_type",
            b"placement_type",
            "resource_name",
            b"resource_name",
            "target_url",
            b"target_url",
        ],
    ) -> None: ...

type___GroupPlacementView = GroupPlacementView



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BidModifierSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___BidModifierSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___BidModifierSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___BidModifierSimulationPointList = BidModifierSimulationPointList

class CpcBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___CpcBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___CpcBidSimulationPointList = CpcBidSimulationPointList

class CpvBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CpvBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___CpvBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___CpvBidSimulationPointList = CpvBidSimulationPointList

class TargetCpaSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___TargetCpaSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___TargetCpaSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___TargetCpaSimulationPointList = TargetCpaSimulationPointList

class TargetRoasSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___TargetRoasSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___TargetRoasSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___TargetRoasSimulationPointList = TargetRoasSimulationPointList

class PercentCpcBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___PercentCpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___PercentCpcBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___PercentCpcBidSimulationPointList = PercentCpcBidSimulationPointList

class BidModifierSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    bid_modifier: builtin___float = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    parent_biddable_conversions: builtin___float = ...
    parent_biddable_conversions_value: builtin___float = ...
    parent_clicks: builtin___int = ...
    parent_cost_micros: builtin___int = ...
    parent_impressions: builtin___int = ...
    parent_top_slot_impressions: builtin___int = ...
    parent_required_budget_micros: builtin___int = ...
    def __init__(
        self,
        *,
        bid_modifier: typing___Optional[builtin___float] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
        parent_biddable_conversions: typing___Optional[builtin___float] = None,
        parent_biddable_conversions_value: typing___Optional[builtin___float] = None,
        parent_clicks: typing___Optional[builtin___int] = None,
        parent_cost_micros: typing___Optional[builtin___int] = None,
        parent_impressions: typing___Optional[builtin___int] = None,
        parent_top_slot_impressions: typing___Optional[builtin___int] = None,
        parent_required_budget_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_parent_biddable_conversions",
            b"_parent_biddable_conversions",
            "_parent_biddable_conversions_value",
            b"_parent_biddable_conversions_value",
            "_parent_clicks",
            b"_parent_clicks",
            "_parent_cost_micros",
            b"_parent_cost_micros",
            "_parent_impressions",
            b"_parent_impressions",
            "_parent_required_budget_micros",
            b"_parent_required_budget_micros",
            "_parent_top_slot_impressions",
            b"_parent_top_slot_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_parent_biddable_conversions",
            b"_parent_biddable_conversions",
            "_parent_biddable_conversions_value",
            b"_parent_biddable_conversions_value",
            "_parent_clicks",
            b"_parent_clicks",
            "_parent_cost_micros",
            b"_parent_cost_micros",
            "_parent_impressions",
            b"_parent_impressions",
            "_parent_required_budget_micros",
            b"_parent_required_budget_micros",
            "_parent_top_slot_impressions",
            b"_parent_top_slot_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_bid_modifier", b"_bid_modifier"],
    ) -> typing_extensions___Literal["bid_modifier"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_biddable_conversions", b"_parent_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["parent_biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_biddable_conversions_value", b"_parent_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["parent_biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_parent_clicks", b"_parent_clicks"],
    ) -> typing_extensions___Literal["parent_clicks"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_cost_micros", b"_parent_cost_micros"
        ],
    ) -> typing_extensions___Literal["parent_cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_impressions", b"_parent_impressions"
        ],
    ) -> typing_extensions___Literal["parent_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_required_budget_micros", b"_parent_required_budget_micros"
        ],
    ) -> typing_extensions___Literal["parent_required_budget_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_parent_top_slot_impressions", b"_parent_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["parent_top_slot_impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___BidModifierSimulationPoint = BidModifierSimulationPoint

class CpcBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    cpc_bid_micros: builtin___int = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        cpc_bid_micros: typing___Optional[builtin___int] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_impressions",
            b"_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_impressions",
            b"_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_cpc_bid_micros", b"_cpc_bid_micros"],
    ) -> typing_extensions___Literal["cpc_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___CpcBidSimulationPoint = CpcBidSimulationPoint

class CpvBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    cpv_bid_micros: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    views: builtin___int = ...
    def __init__(
        self,
        *,
        cpv_bid_micros: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        views: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cost_micros",
            b"_cost_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_impressions",
            b"_impressions",
            "_views",
            b"_views",
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cost_micros",
            b"_cost_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_impressions",
            b"_impressions",
            "_views",
            b"_views",
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_cpv_bid_micros", b"_cpv_bid_micros"],
    ) -> typing_extensions___Literal["cpv_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_views", b"_views"]
    ) -> typing_extensions___Literal["views"]: ...

type___CpvBidSimulationPoint = CpvBidSimulationPoint

class TargetCpaSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_cpa_micros: builtin___int = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        target_cpa_micros: typing___Optional[builtin___int] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions___Literal["target_cpa_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___TargetCpaSimulationPoint = TargetCpaSimulationPoint

class TargetRoasSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    target_roas: builtin___float = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        target_roas: typing___Optional[builtin___float] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_roas",
            b"_target_roas",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_roas",
            b"_target_roas",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions___Literal["target_roas"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___TargetRoasSimulationPoint = TargetRoasSimulationPoint

class PercentCpcBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    percent_cpc_bid_micros: builtin___int = ...
    biddable_conversions: builtin___float = ...
    biddable_conversions_value: builtin___float = ...
    clicks: builtin___int = ...
    cost_micros: builtin___int = ...
    impressions: builtin___int = ...
    top_slot_impressions: builtin___int = ...
    def __init__(
        self,
        *,
        percent_cpc_bid_micros: typing___Optional[builtin___int] = None,
        biddable_conversions: typing___Optional[builtin___float] = None,
        biddable_conversions_value: typing___Optional[builtin___float] = None,
        clicks: typing___Optional[builtin___int] = None,
        cost_micros: typing___Optional[builtin___int] = None,
        impressions: typing___Optional[builtin___int] = None,
        top_slot_impressions: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions___Literal["biddable_conversions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions___Literal["biddable_conversions_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_clicks", b"_clicks"]
    ) -> typing_extensions___Literal["clicks"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions___Literal["cost_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_impressions", b"_impressions"]
    ) -> typing_extensions___Literal["impressions"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_percent_cpc_bid_micros", b"_percent_cpc_bid_micros"
        ],
    ) -> typing_extensions___Literal["percent_cpc_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions___Literal["top_slot_impressions"]: ...

type___PercentCpcBidSimulationPoint = PercentCpcBidSimulationPoint



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LocationExtensionTargetingCriterionFieldEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LocationExtensionTargetingCriterionFieldValue = typing___NewType(
        "LocationExtensionTargetingCriterionFieldValue", builtin___int
    )
    type___LocationExtensionTargetingCriterionFieldValue = (
        LocationExtensionTargetingCriterionFieldValue
    )
    LocationExtensionTargetingCriterionField: _LocationExtensionTargetingCriterionField
    class _LocationExtensionTargetingCriterionField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            0,
        )
        UNKNOWN = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            1,
        )
        ADDRESS_LINE_1 = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            2,
        )
        ADDRESS_LINE_2 = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            3,
        )
        CITY = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            4,
        )
        PROVINCE = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            5,
        )
        POSTAL_CODE = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            6,
        )
        COUNTRY_CODE = typing___cast(
            LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
            7,
        )
    UNSPECIFIED = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        0,
    )
    UNKNOWN = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        1,
    )
    ADDRESS_LINE_1 = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        2,
    )
    ADDRESS_LINE_2 = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        3,
    )
    CITY = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        4,
    )
    PROVINCE = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        5,
    )
    POSTAL_CODE = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        6,
    )
    COUNTRY_CODE = typing___cast(
        LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldValue,
        7,
    )
    type___LocationExtensionTargetingCriterionField = (
        LocationExtensionTargetingCriterionField
    )
    def __init__(self,) -> None: ...

type___LocationExtensionTargetingCriterionFieldEnum = (
    LocationExtensionTargetingCriterionFieldEnum
)



from typing import Any

class CampaignLabelServiceStub:
    GetCampaignLabel: Any = ...
    MutateCampaignLabels: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignLabelServiceServicer:
    def GetCampaignLabel(self, request: Any, context: Any) -> None: ...
    def MutateCampaignLabels(self, request: Any, context: Any) -> None: ...

def add_CampaignLabelServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
